==> tencentcloud-sdk-java-3.1.888-sources.jar: com/tencentcloudapi/cds/v20180420/models/DescribeDasbImageIdsResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cds.v20180420.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeDasbImageIdsResponse extends AbstractModel {

    /**
    * 基础镜像ID
    */
    @SerializedName("BaseImageId")
    @Expose
    private String BaseImageId;

    /**
    * AI镜像ID
    */
    @SerializedName("AiImageId")
    @Expose
    private String AiImageId;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 基础镜像ID 
     * @return BaseImageId 基础镜像ID
     */
    public String getBaseImageId() {
        return this.BaseImageId;
    }

    /**
     * Set 基础镜像ID
     * @param BaseImageId 基础镜像ID
     */
    public void setBaseImageId(String BaseImageId) {
        this.BaseImageId = BaseImageId;
    }

    /**
     * Get AI镜像ID 
     * @return AiImageId AI镜像ID
     */
    public String getAiImageId() {
        return this.AiImageId;
    }

    /**
     * Set AI镜像ID
     * @param AiImageId AI镜像ID
     */
    public void setAiImageId(String AiImageId) {
        this.AiImageId = AiImageId;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeDasbImageIdsResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeDasbImageIdsResponse(DescribeDasbImageIdsResponse source) {
        if (source.BaseImageId != null) {
            this.BaseImageId = new String(source.BaseImageId);
        }
        if (source.AiImageId != null) {
            this.AiImageId = new String(source.AiImageId);
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "BaseImageId", this.BaseImageId);
        this.setParamSimple(map, prefix + "AiImageId", this.AiImageId);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.1000-sources.jar: com/tencentcloudapi/cds/v20180420/models/DescribeDasbImageIdsResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cds.v20180420.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeDasbImageIdsResponse extends AbstractModel {

    /**
    * 基础镜像ID
    */
    @SerializedName("BaseImageId")
    @Expose
    private String BaseImageId;

    /**
    * AI镜像ID
    */
    @SerializedName("AiImageId")
    @Expose
    private String AiImageId;

    /**
    * 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 基础镜像ID 
     * @return BaseImageId 基础镜像ID
     */
    public String getBaseImageId() {
        return this.BaseImageId;
    }

    /**
     * Set 基础镜像ID
     * @param BaseImageId 基础镜像ID
     */
    public void setBaseImageId(String BaseImageId) {
        this.BaseImageId = BaseImageId;
    }

    /**
     * Get AI镜像ID 
     * @return AiImageId AI镜像ID
     */
    public String getAiImageId() {
        return this.AiImageId;
    }

    /**
     * Set AI镜像ID
     * @param AiImageId AI镜像ID
     */
    public void setAiImageId(String AiImageId) {
        this.AiImageId = AiImageId;
    }

    /**
     * Get 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeDasbImageIdsResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeDasbImageIdsResponse(DescribeDasbImageIdsResponse source) {
        if (source.BaseImageId != null) {
            this.BaseImageId = new String(source.BaseImageId);
        }
        if (source.AiImageId != null) {
            this.AiImageId = new String(source.AiImageId);
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "BaseImageId", this.BaseImageId);
        this.setParamSimple(map, prefix + "AiImageId", this.AiImageId);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
